==> react-composer-3.1.0.tgz: package/es/index.js <==
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import React from 'react';
import PropTypes from 'prop-types';

export default function Composer(_ref) {
  var _ref$components = _ref.components,
      components = _ref$components === undefined ? [] : _ref$components,
      children = _ref.children,
      renderPropName = _ref.renderPropName,
      mapResult = _ref.mapResult;

  if (typeof children !== 'function') {
    return null;
  }

  // This is the argument that we pass into `children`.
  var results = [];

  // This is the list of components, reversed. We reverse them because the
  // component that you list last will be the highest in the tree.
  var reversedComponents = components.reverse();

  function chainComponents(childrenComponents) {
    // When we reach the end of our `childrenComponents`, we can render out
    // the response array.
    if (childrenComponents.length === 0) {
      return children([].concat(results));
    }

    var componentIndex = childrenComponents.length - 1;

    var component =
    // Each props.components entry is either an element or function [element factory]
    // When it is a function, produce an element by invoking it with currently accumulated results.
    typeof components[componentIndex] === 'function' ? components[componentIndex](results) : components[componentIndex];

    // This is the index of where we should place the response within `results`.
    // It's not the same as `componentIndex` because we reversed the components when
    // rendering out the components.
    // In a sense, it can be thought of as the "reverse" index of `componentIndex`.
    var responseIndex = reversedComponents.length - childrenComponents.length;

    // We create a clone of the childrenComponents so that subsequent calls to `chidlren`
    // render the same tree. If we modified `reversedComponents` directly, then the tree would
    // be different with each call to `children`.
    var childrenComponentsClone = [].concat(_toConsumableArray(childrenComponents));
    childrenComponentsClone.pop();

    return React.cloneElement(component, _defineProperty({}, renderPropName, function () {
      if (mapResult) {
        results[responseIndex] = mapResult.apply(null, arguments);
      } else {
        results[responseIndex] = arguments[0];
      }
      return chainComponents(childrenComponentsClone);
    }));
  }

  return chainComponents(reversedComponents);
}

Composer.propTypes = {
  children: PropTypes.func,
  components: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.element, PropTypes.func])),
  renderPropName: PropTypes.string,
  mapResult: PropTypes.func
};

Composer.defaultProps = {
  renderPropName: 'children'
};

==> react-composer-3.1.1.tgz: package/es/index.js <==
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import React from 'react';
import PropTypes from 'prop-types';

export default function Composer(_ref) {
  var _ref$components = _ref.components,
      components = _ref$components === undefined ? [] : _ref$components,
      children = _ref.children,
      renderPropName = _ref.renderPropName,
      mapResult = _ref.mapResult;

  if (typeof children !== 'function') {
    return null;
  }

  // This is the argument that we pass into `children`.
  var results = [];

  // This is the list of components, reversed. We reverse them because the
  // component that you list last will be the highest in the tree.
  var reversedComponents = components.reverse();

  function chainComponents(childrenComponents) {
    // When we reach the end of our `childrenComponents`, we can render out
    // the response array.
    if (childrenComponents.length === 0) {
      return children([].concat(results));
    }

    var componentIndex = childrenComponents.length - 1;

    var component =
    // Each props.components entry is either an element or function [element factory]
    // When it is a function, produce an element by invoking it with currently accumulated results.
    typeof components[componentIndex] === 'function' ? components[componentIndex]([].concat(results)) : components[componentIndex];

    // This is the index of where we should place the response within `results`.
    // It's not the same as `componentIndex` because we reversed the components when
    // rendering out the components.
    // In a sense, it can be thought of as the "reverse" index of `componentIndex`.
    var responseIndex = reversedComponents.length - childrenComponents.length;

    // We create a clone of the childrenComponents so that subsequent calls to `chidlren`
    // render the same tree. If we modified `reversedComponents` directly, then the tree would
    // be different with each call to `children`.
    var childrenComponentsClone = [].concat(_toConsumableArray(childrenComponents));
    childrenComponentsClone.pop();

    return React.cloneElement(component, _defineProperty({}, renderPropName, function () {
      if (mapResult) {
        results[responseIndex] = mapResult.apply(null, arguments);
      } else {
        results[responseIndex] = arguments[0];
      }
      return chainComponents(childrenComponentsClone);
    }));
  }

  return chainComponents(reversedComponents);
}

Composer.propTypes = {
  children: PropTypes.func,
  components: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.element, PropTypes.func])),
  renderPropName: PropTypes.string,
  mapResult: PropTypes.func
};

Composer.defaultProps = {
  renderPropName: 'children'
};
